@@ -51,7 +51,7 @@ class APIFunction(LambdaFunction):
             "Access-Control-Allow-Methods": "*",
         }
         return_obj["headers"] = headers
-        if body:
+        if body or isinstance(body, list):
             return_obj["body"] = json.dumps(body, default=datetime.isoformat)
         return return_obj
 
